==> webStore_2.8.2_estable.zip: admin/html_files/componentes/banners/fotos_abrir_carpeta.php <==
<?php
	//Creado por Pedro el 13/Febrero/2019 ==> Imagen que permite subir un nivel en los directorios:
	$ruta_enlace = '';
	$nombre_carpeta = '';
	$nombreCompletoCarpeta = '';
	$nombre_icono = 'mdi mdi-folder-upload';
	if (isset($fileParams)){
		if (isset($fileParams->args)){
			if (is_array($fileParams->args)){
				if (isset($fileParams->args[1])){
					$ruta_enlace = $fileParams->args[1];	// Sí, hay que liar mucho para llegar, pero mejor asegurarse
				}
				if (isset($fileParams->args[2])){
					$nombre_carpeta = $fileParams->args[2];	// Sí, hay que liar mucho para llegar, pero mejor asegurarse
				}
				if (isset($fileParams->args[3])){
					$nombre_icono = $fileParams->args[3];	// Sí, hay que liar mucho para llegar, pero mejor asegurarse
				}
				if (isset($fileParams->args[4])){
					$nombreCompletoCarpeta = $fileParams->args[4];	// Sí, hay que liar mucho para llegar, pero mejor asegurarse
				}
			}
		}
	}

	if ($ruta_enlace != ''){
		//$ruta_enlace contiene la ruta de carpetas:
?>

<div class="col-lg-3 col-md-6" data-ruta="<?=$ruta_enlace;?>">
	<div class="card">
		<div class="el-card-item">
			<div class="el-card-avatar el-overlay-1"> 
				<div class="el-overlay carpeta">
					<ul class="list-style-none el-info">
						<li class="el-item"><a class="el-link" href="javascript:void(0);" onclick="
							var sendData = { 'ruta_img_actual' : '<?=$ruta_enlace;?>'};
							WS_data_update(
								'Sesion',
								'set',
								sendData,
								'=\'img_list_change\'',
								function(data){}
							);
						"><i class="<?=$nombre_icono;?>"></i></a></li>
					</ul>
				</div>
			</div>
			<div class="el-card-content row">
				<div class="col-md-10">
					<h4 class="m-b-0"><?=$nombre_carpeta;?></h4>
				</div>
<?php
	//Cuando estemos en un botón de volver atrás no hay que mostrar este botón:
	if ($nombre_carpeta != traducir('Atrás')){
?>
				<div class="col-md-1">
					<button type="button" class="btn btn-danger btn-lg" onclick="
					var diapositiva = $(this).closest('[data-ruta]');
					if (confirm('<?=traducir('¿Desea eliminar esta carpeta?');?>')){
						//Con este script comprobamos si la carpeta está vacía
						var sendData = { 'path' : '<?=$nombreCompletoCarpeta;?>'};
						WS_data_update(
							'FileSystem',
							'dirIsEmpty',
							sendData,
							'',
							function(data){
								var error = true;
								if (data.response != null){
									data.response = JSON.parse(data.response);
									if (data.response.resultado == true){
										//Vamos a enviar la solicitud de borrado:
										var sendData = { 'path' : '<?=$nombreCompletoCarpeta;?>'};
										WS_data_update(
											'FileSystem',
											'deleteDir',
											sendData,
											'',
											function(data){
												//Comprobamos si hemos recibido 'response'
												var error = true;
												if (data.response != null){
													data.response = JSON.parse(data.response);
													if (data.response.resultado == true){
														//Vamos a enviar la solicitud de borrado:
														diapositiva.fadeOut(300, function() { $(this).remove(); });
													}else{
														alert('<?=traducir('Error al borrar el directorio. No está vacío.');?>');
													}
												}
											}
										);
									}else{
										alert('<?=traducir('Error al borrar el directorio. No está vacío.');?>');
									}
								}
							}
						);
					}
					"><i class="mdi mdi-delete-empty"/></i></button>
				</div>
<?php
	}
?>
			</div>
		</div>
	</div>
</div>
<?php
	}

==> webStore_2.8.9.003_estable.zip: admin/html_files/componentes/banners/fotos_abrir_carpeta.php <==
<?php
	//Creado por Pedro el 13/Febrero/2019 ==> Imagen que permite subir un nivel en los directorios:
	$ruta_enlace = (Theme::getLastParam(1)) ? Theme::getLastParam(1) : '';
	$nombre_carpeta = (Theme::getLastParam(2)) ? Theme::getLastParam(2) : '';
	$nombreCompletoCarpeta = (Theme::getLastParam(4)) ? Theme::getLastParam(4) : '';
	$nombre_icono = (Theme::getLastParam(3)) ? Theme::getLastParam(3) : 'mdi mdi-folder-upload';

	if ($ruta_enlace != ''){
		//$ruta_enlace contiene la ruta de carpetas:
?>

<div class="col-lg-3 col-md-6" data-ruta="<?=$ruta_enlace;?>">
	<div class="card">
		<div class="el-card-item">
			<div class="el-card-avatar el-overlay-1"> 
				<div class="el-overlay carpeta">
					<ul class="list-style-none el-info">
						<li class="el-item"><a class="el-link" href="javascript:void(0);" onclick="
							var sendData = { 'ruta_img_actual' : '<?=$ruta_enlace;?>'};
							WS_data_update(
								'Sesion',
								'set',
								sendData,
								'=\'img_list_change\'',
								function(data){}
							);
						"><i class="<?=$nombre_icono;?>"></i></a></li>
					</ul>
				</div>
			</div>
			<div class="el-card-content row">
				<div class="col-md-10">
					<h4 class="m-b-0"><?=$nombre_carpeta;?></h4>
				</div>
<?php
	//Cuando estemos en un botón de volver atrás no hay que mostrar este botón:
	if ($nombre_carpeta != traducir('Atrás')){
?>
				<div class="col-md-1">
					<button type="button" class="btn btn-danger btn-lg" onclick="
					var diapositiva = $(this).closest('[data-ruta]');
					if (confirm('<?=traducir('¿Desea eliminar esta carpeta?');?>')){
						//Con este script comprobamos si la carpeta está vacía
						var sendData = { 'path' : '<?=$nombreCompletoCarpeta;?>'};
						WS_data_update(
							'FileSystem',
							'dirIsEmpty',
							sendData,
							'',
							function(data){
								var error = true;
								if (data.response != null){
									data.response = JSON.parse(data.response);
									if (data.response.resultado == true){
										//Vamos a enviar la solicitud de borrado:
										var sendData = { 'path' : '<?=$nombreCompletoCarpeta;?>'};
										WS_data_update(
											'FileSystem',
											'deleteDir',
											sendData,
											'',
											function(data){
												//Comprobamos si hemos recibido 'response'
												var error = true;
												if (data.response != null){
													data.response = JSON.parse(data.response);
													if (data.response.resultado == true){
														//Vamos a enviar la solicitud de borrado:
														diapositiva.fadeOut(300, function() { $(this).remove(); });
													}else{
														alert('<?=traducir('Error al borrar el directorio. No está vacío.');?>');
													}
												}
											}
										);
									}else{
										alert('<?=traducir('Error al borrar el directorio. No está vacío.');?>');
									}
								}
							}
						);
					}
					"><i class="mdi mdi-delete-empty"/></i></button>
				</div>
<?php
	}
?>
			</div>
		</div>
	</div>
</div>
<?php
	}
